#ifndef EL__ECMASCRIPT_MUJS_UNIBAR_H
#define EL__ECMASCRIPT_MUJS_UNIBAR_H

#include <mujs.h>

#ifdef __cplusplus
extern "C" {
#endif

int mjs_unibar_init(js_State *J);

#ifdef __cplusplus
}
#endif

#endif
